package ca.uwaterloo.gp.editorlist;

/**********************************************************************
Copyright (c) 2002 IBM Corp.  All rights reserved.
This file is made available under the terms of the Common Public License v1.0
which accompanies this distribution, and is available at
http://www.eclipse.org/legal/cpl-v10.html
*********************************************************************/

import java.util.HashMap;
import java.util.Map;

import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IWorkbenchPage;

/**
 * The EditorListContentProvider supplies the EditorList
 * view with items to display in its table view.
 * The items returned are the <code>IEditorReference</code>s currently
 * open in the workbench.
 */
public class EditorListContentProvider implements IStructuredContentProvider {
	private Map fElementMap= new HashMap();

	/**
	 * @see IStructuredContentProvider#getElements(Object)
	 */
	public Object[] getElements(Object inputElement) {
		IEditorReference references[]= ((IWorkbenchPage)inputElement).getEditorReferences();
		EditorListElement elements[]= new EditorListElement[references.length];
		EditorListElement element;
		fElementMap.clear();
		for (int i= 0, numReferences= references.length; i < numReferences; i++) {
			element= new EditorListElement(references[i]);
			fElementMap.put(references[i], element);
			elements[i]= element;
		}
		return elements;
	}
	
	/**
	 * Returns the <code>EditorListElement</code> that wrappers the
	 * given editor reference or <code>null</code> if no such wrapper exists.
	 */
	public EditorListElement getElement(IEditorReference reference) {
		return (EditorListElement)fElementMap.get(reference);
	}
	
	/**
	 * Removes the given editor reference from the mapping of
	 * <code>EditorListElement</code> mappings.
	 * 
	 * @param reference the editor to remove
	 * @return EditorListElement the element previously associated with the
	 * given reference of <code>null</code> if none
	 */
	public EditorListElement removeElement(IEditorReference reference) {
		return (EditorListElement) fElementMap.remove(reference);
	}
	
	/**
	 * Adds an element to the content provider that wrappers the given
	 * reference. The new element is added to the
	 * <code>EditorListElement</code> mappings.
	 * 
	 * @param reference the editor reference to wrapper
	 * @return EditorListElement the element that is created to wrapper the
	 * given reference
	 */
	public EditorListElement addElement(IEditorReference reference) {
		EditorListElement element = new EditorListElement(reference);
		fElementMap.put(reference, element);
		return element;
	}

	/*
	 * @see IContentProvider#dispose()
	 */
	public void dispose() {
	}

	/*
	 * @see IContentProvider#inputChanged(Viewer, Object, Object)
	 */
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
	}

}
