package ca.uwaterloo.gp.editorlist;

/**********************************************************************
Copyright (c) 2002 IBM Corp.  All rights reserved.
This file is made available under the terms of the Common Public License v1.0
which accompanies this distribution, and is available at
http://www.eclipse.org/legal/cpl-v10.html
*********************************************************************/

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.Platform;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IFileEditorInput;
import org.eclipse.ui.PlatformUI;

/**
 * An editor list element is a wrapper to an <code>IEditorReference</code>
 * object that is displayed in an <code>EditorList</code>. Editor list elements
 * are <code>IAdaptable</code> to resources so that menu items contributed to
 * resources will appear in the editor list view.
 */
public class EditorListElement implements IAdaptable {

	private IEditorReference fEditorReference;

	/**
	 * Creates a new editor list element that wrappers the given editor
	 * reference.
	 * 
	 * @param reference the editor reference that this editor list element will
	 * wrap.
	 */
	public EditorListElement(IEditorReference reference) {
		fEditorReference = reference;
	}

	/**
	 * Returns the editor reference that this editor list element wrappers.
	 * 
	 * @return IEditorReference this editor list element's underlying editor
	 * reference.
	 */
	public IEditorReference getEditorReference() {
		return fEditorReference;
	}

	/**
	 * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
	 */
	public Object getAdapter(Class adapter) {
		if (IResource.class.equals(adapter)) {
			if (!PlatformUI.getPreferenceStore().getBoolean(IEditorListConstants.PREF_SHOW_RESOURCE_ATTRIBUTES)) {
				return null;
			}
			IEditorPart part = (fEditorReference).getEditor(true);
			if (part != null) {
				IEditorInput input = part.getEditorInput();
				if (input instanceof IFileEditorInput) {
					return ((IFileEditorInput) input).getFile();
				}
			}
			return null;
		}
		return Platform.getAdapterManager().getAdapter(this, adapter);
	}

}
