package ca.uwaterloo.gp.editorlist;

/**********************************************************************
Copyright (c) 2002 IBM Corp.  All rights reserved.
This file is made available under the terms of the Common Public License v1.0
which accompanies this distribution, and is available at
http://www.eclipse.org/legal/cpl-v10.html
*********************************************************************/

import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.eclipse.ui.PlatformUI;

/**
 * Preference page to configure preferences for the EditorList view
 */
public class EditorListPreferencePage extends PreferencePage implements IWorkbenchPreferencePage {
	
	Button fResourceAttributesButton;

	/**
	 * Creates a new preference page for the EditorList view
	 */
	public EditorListPreferencePage() {
		setDescription(EditorListMessages.getString("EditorListPreferencePage.0")); //$NON-NLS-1$
		setPreferenceStore(PlatformUI.getPreferenceStore());
	}

	/**
	 * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
	 */
	protected Control createContents(Composite parent) {
		Font font = parent.getFont();
		
		//The main composite
		Composite composite = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		layout.numColumns = 1;
		layout.marginHeight=0;
		layout.marginWidth=0;
		composite.setLayout(layout);
		GridData data = new GridData();
		data.verticalAlignment = GridData.FILL;
		data.horizontalAlignment = GridData.FILL;
		composite.setLayoutData(data);
		
		Group resourceFeaturesGroup= new Group(composite, SWT.NONE);
		data= new GridData(GridData.FILL_HORIZONTAL);
		resourceFeaturesGroup.setLayoutData(data);
		layout= new GridLayout();
		resourceFeaturesGroup.setLayout(layout);
		resourceFeaturesGroup.setFont(font);
		
		fResourceAttributesButton= new Button(resourceFeaturesGroup, SWT.CHECK | SWT.LEFT);
		fResourceAttributesButton.setFont(font);
		fResourceAttributesButton.setText(EditorListMessages.getString("EditorListPreferencePage.1")); //$NON-NLS-1$
		fResourceAttributesButton.setToolTipText(EditorListMessages.getString("EditorListPreferencePage.2")); //$NON-NLS-1$
		fResourceAttributesButton.setSelection(getPreferenceStore().getBoolean(IEditorListConstants.PREF_SHOW_RESOURCE_ATTRIBUTES));
		
		createNoteComposite(font, resourceFeaturesGroup, EditorListMessages.getString("EditorListPreferencePage.3"), EditorListMessages.getString("EditorListPreferencePage.4")); //$NON-NLS-1$ //$NON-NLS-2$
		
		return composite;
	}

	/**
	 * @see org.eclipse.jface.preference.PreferencePage#performDefaults()
	 */
	protected void performDefaults() {
		fResourceAttributesButton.setSelection(getPreferenceStore().getDefaultBoolean(IEditorListConstants.PREF_SHOW_RESOURCE_ATTRIBUTES));
		super.performDefaults();
	}

	/**
	 * @see org.eclipse.jface.preference.IPreferencePage#performOk()
	 */
	public boolean performOk() {
		getPreferenceStore().setValue(IEditorListConstants.PREF_SHOW_RESOURCE_ATTRIBUTES, fResourceAttributesButton.getSelection());
		EditorList[] views= EditorList.getEditorLists();
		for (int i = 0; i < views.length; i++) {
			views[i].refreshContents();
		}
		return super.performOk();
	}
	/**
	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
	 */
	public void init(IWorkbench workbench) {
	}
	
	/**
	 * Creates a composite with a highlighted Note entry and a message text.
	 * This is designed to take up the full width of the page.
	 * 
	 * @param font the font to use
	 * @param composite the parent composite
	 * @param title the title of the note
	 * @param message the message for the note
	 * @return the composite for the note
	 */
	protected Composite createNoteComposite(
		Font font,
		Composite composite,
		String title,
		String message) {
		Composite messageComposite = new Composite(composite, SWT.NONE);
		GridLayout messageLayout = new GridLayout();
		messageLayout.numColumns = 2;
		messageLayout.marginWidth = 0;
		messageLayout.marginHeight = 0;
		messageComposite.setLayout(messageLayout);
		messageComposite.setLayoutData(
			new GridData(GridData.HORIZONTAL_ALIGN_FILL));
		messageComposite.setFont(font);

		final Label noteLabel = new Label(messageComposite, SWT.BOLD);
		noteLabel.setText(title);
		noteLabel.setFont(JFaceResources.getBannerFont());
		noteLabel.setLayoutData(
			new GridData(GridData.VERTICAL_ALIGN_BEGINNING));

		final IPropertyChangeListener fontListener =
			new IPropertyChangeListener() {
			public void propertyChange(PropertyChangeEvent event) {
				if (JFaceResources.BANNER_FONT.equals(event.getProperty())) {
					noteLabel.setFont(
						JFaceResources.getFont(JFaceResources.BANNER_FONT));
				}
			}
		};
		JFaceResources.getFontRegistry().addListener(fontListener);
		noteLabel.addDisposeListener(new DisposeListener() {
			public void widgetDisposed(DisposeEvent event) {
				JFaceResources.getFontRegistry().removeListener(fontListener);
			}
		});

		Label messageLabel = new Label(messageComposite, SWT.WRAP);
		messageLabel.setText(message);
		messageLabel.setFont(font);
		return messageComposite;
	}

}
