package ca.uwaterloo.gp.editorlist;

/**********************************************************************
Copyright (c) 2002, 2005 IBM Corp.  All rights reserved.
This file is made available under the terms of the Common Public License v1.0
which accompanies this distribution, and is available at
http://www.eclipse.org/legal/cpl-v10.html
*********************************************************************/

import java.net.URL;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.MultiStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkingSet;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.dialogs.IWorkingSetSelectionDialog;
import org.eclipse.ui.ide.IDE;

/**
 * The OpenEditorWorkingSetAction allows the user to
 * open a working set of editors.
 */
public class OpenEditorWorkingSetAction extends Action {

	public OpenEditorWorkingSetAction() {
		super();
		
		URL url= Platform.getBundle("EditorList").getEntry("icons/full/clcl16/open_workingset.gif");
		if (url != null) {
			setImageDescriptor(ImageDescriptor.createFromURL(url));
		}
		setDescription(EditorListMessages.getString("ShowEditorWorkingSetAction.Open_editor_working_set_1"));
		setToolTipText(EditorListMessages.getString("ShowEditorWorkingSetAction.Open_working_set_2"));
		setText(EditorListMessages.getString("OpenEditorWorkingSetAction.Open_working_set_1"));
	}
	
	public void run() {
		IWorkbenchPage page= PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
		IWorkingSetSelectionDialog dialog= PlatformUI.getWorkbench().getWorkingSetManager().createWorkingSetSelectionDialog(page.getActivePart().getSite().getShell(), true);
		dialog.open();
		IWorkingSet sets[]= dialog.getSelection();
		if (sets == null) {
			return;
		}
		MultiStatus status= new MultiStatus(IEditorListConstants.PLUGIN_ID, IStatus.ERROR, EditorListMessages.getString("OpenEditorWorkingSetAction.5"), null); //$NON-NLS-1$
		for (int i= 0, numSets= sets.length; i < numSets; i++) {
			IAdaptable[] elements= sets[i].getElements();
			for (int j= 0, numElements= elements.length; j < numElements; j++) {
				IAdaptable element= elements[j];
				if (!(element instanceof IFile)) {
					continue;
				}
				try {
					IDE.openEditor(page, (IFile) element);
				} catch(PartInitException e) {
					status.merge(e.getStatus());
				}
			}
		}
		if (!status.isOK()) {
			ErrorDialog.openError(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(), EditorListMessages.getString("OpenEditorWorkingSetAction.6"), status.getMessage(), status); //$NON-NLS-1$
		}
	}

}
