package ca.uwaterloo.gp.editorlist;

/**********************************************************************
Copyright (c) 2002 IBM Corp.  All rights reserved.
This file is made available under the terms of the Common Public License v1.0
which accompanies this distribution, and is available at
http://www.eclipse.org/legal/cpl-v10.html
*********************************************************************/

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.ViewerSorter;

/**
 * The SortEditorListAction toggles the sorter activation
 * for a viewer.
 */
public class SortEditorListAction extends Action {
	
	private TableViewer fViewer;
	private ViewerSorter fSorter;
	
	/**
	 * Creates a new sort action.
	 * @param viewer the viewer for which this action will
	 *  toggle sorting.
	 */
	public SortEditorListAction(TableViewer viewer) {
		super();
		fViewer= viewer;
		fSorter= new ViewerSorter();

		URL url = null;
		try {
			url = new URL(Platform.getBundle("EditorList").getEntry("/"), "icons/full/clcl16/alpha_mode.gif");
		} catch (MalformedURLException e) {
		}
		setImageDescriptor(ImageDescriptor.createFromURL(url));
		
		// TODO: Persist sort state
		setChecked(false);
		setSort(false);
	}
	
	/**
	 * Sets sorting based on the checked state.
	 */
	public void run() {
		setSort(isChecked());
	}
	
	/**
	 * Turns sorting on or off.
	 * 
	 * @param sort whether or not sorting should be turned on
	 */
	protected void setSort(boolean sort) {
		fViewer.setSorter(sort ? fSorter : null);
		
		setToolTipText(sort ? EditorListMessages.getString("SortEditorListAction.Do_not_sort_2") : EditorListMessages.getString("SortEditorListAction.Sort_3"));
		setDescription(sort ? EditorListMessages.getString("SortEditorListAction.Disable_sorting_4") : EditorListMessages.getString("SortEditorListAction.Enable_sorting_5"));
	}

}
